
/* Internetové rádio AURUINO UNO ( nebo kompatibilní ), VS 1053B Shield ( nebo kompatibilní )
*  Ethernet Shield W5100 R3, LCD displej I2C, 2 tlačítka se spínacím kontaktem
*  
* Autor :  David Kohout 12 / 2019
*
*/

//   Standartní knihovny
#include <VS1053.h>             // Standartní knihovna VS1053  ( Funguje i pod naším Shieldem, originál knihovnu SFEMP3Shield nepožívat,                        

#include <Ethernet.h>           // Standartní knihovna Ethernet - Shield W5100
#include <Bounce2.h>            // Vyhodnocení stavu tlačítek - autor Thomas Ouellet Fredericks
#include <LiquidCrystal_I2C.h>  // Knihovna LCD displeje


#define B_PREV 3   // Tlačítko předchozí stanice připojeno mezi GND a pin 5 Arduino UNO
#define B_NEXT 5   // Tlačítko další stanice připojeno mezi GND a pin 3 Arduino UNO
#define BUTTON_DEBOUNCE_PERIOD 20 // Perioda snímání stavu tlačítek v milisekundách


Bounce b_Next  = Bounce(); // Makro tlačítko NEXT ( další stanice )

Bounce b_Prev  = Bounce(); // Makro tlačítko PREV ( předchozí stanice )

// SPI porty ARDUINA MEGA

// 50 - MISO           Při použití ARDUINO MEGA proklemovat 50 Arduino na 12 pin zvukovky
// 51 - MOSI           Při použití ARDUINO MEGA proklemovat 51 Arduino na 11 pin zvukovky
// 52 - SCK            Při použití ARDUINO MEGA proklemovat 52 Arduino na 13 pin zvukovky

// ---------  Nemusí se ohýbat nožičky ze Shieldu, prostě natvrdo dát klemu -----------

VS1053 MP3player(6,7,2,8);  // X_CS 6 pin, X_DCS 7 pin, DREQ 2 pin, X_RESET 8 pin

byte mac[] = {0xDE, 0xAD, 0xBE, 0xEF, 0xFE, 0xED}; // Přiřazení MAC adresy síťovce - možno změnit

EthernetClient client;  // Ethernet jako klient

LiquidCrystal_I2C lcd(0x27, 16, 2); // LCD na adrese 0x27, 16 znaků, 2 řádky  
//--------------------------------------------------------------------------------------------------------//

//--------------------------------------------------------------------------------------------------------//
uint8_t mp3buff[32];       // Velikost bufferu 32 Byte
const char *host;          // Zde se uloží adresa serveru s požadovaným streamem
const char *path;          // Zde se uloží cesta serveru s požadovaným streamem
int httpPort;              // Zde se uloží port serveru s požadovaným streamem
int ID_stanice=7;          // Zde se uloží číslo aktuálně přehrávané stanice - konstanta číslo stanice, které začne hrát po spuštění Arduina 
int pamet_ID_stanice;      // Zde se uloží číslo posledně přehrávané stanice
const char *nazev;         // Zde se uloží jméno aktuálně přehrávané stanice


void setup() {
   
pinMode(B_PREV,INPUT_PULLUP);  // Definování tlačítka předchozí stanice
pinMode(B_NEXT,INPUT_PULLUP);  // Definování tlačítka následující stanice

  b_Next.attach(B_NEXT);     // Aktivace makra pro tlačítko další stanice
  b_Next.interval(BUTTON_DEBOUNCE_PERIOD);  // Perioda snímání stavu tlačítka - 20 ms.

  b_Prev.attach(B_PREV);     // Aktivace makra pro tlačítko předchozí stanice
  b_Prev.interval(BUTTON_DEBOUNCE_PERIOD);  // Perioda snímání stavu tlačítka - 20 ms.

 Ethernet.begin(mac);      // Start Ethernetového spojení, IP adresu přiřadí router

 MP3player.begin();        // Start zvukové karty VS1053B Shield
 MP3player.setVolume(10);  // Nižší číslo vyšší hlasitost
 lcd.init();               // Inicializace LCD displeje
 lcd.backlight();          // Podsvícení LCD displeje

    
    client.print(String("GET ") + path + " HTTP/1.1\r\n" +                    // Adresa serveru se streamem - požadavek při spuštění Arduina
                  "Host: " + host + "\r\n" + 
                  "Connection: close\r\n\r\n");
                  
}



void loop() {            // Hlavní program - smyčka

if (b_Next.update()) {
    if (b_Next.read() == LOW && ID_stanice <18) {  // Detekována sestupná hrana tlačítka NEXT a není-li rádio aktuálně na poslední stanici, tak :
      
      ID_stanice=ID_stanice +1;                  // Připočti číslo 1 k číslu aktuálně přehrávané stanice
     
    }
  }

  if (b_Prev.update()) {
    if (b_Prev.read() == LOW&& ID_stanice >1) {  // Detekována sestupná hrana tlačítka PREV a není-li rádio aktuálně na první stanici, tak :
      
      ID_stanice=ID_stanice -1;                  // Odečti číslo 1 od čísla aktuálně přehrávané stanice
      
     
    }
  }


                                                                                                                
switch(ID_stanice){              // Přepínání stanic - ID stanice
        case 1:
             nazev = " Hitradio 80 CZ";       
             host = "ice.abradio.cz";         // Hitrádio 80
             path = "/hit80128.mp3";
             httpPort = 80;
            break;
        case 2:
           nazev = " Hitradio 90 CZ"; 
           host= "ice.abradio.cz";         // Hitrádio 90
           path = "/hit90128.mp3";
           httpPort = 80;
            break;
        case 3:
            nazev = " Star*Sat Radio"; 
            host = "starsat-ais-edge-3005.fra-eco.cdn.addradio.net";       // DE STAR*SAT RADIO
            path = "/starsat/live/mp3/low/stream.mp3";
            httpPort = 80;;
            break;
        case 4:
            nazev = "Antene Bayern 80"; 
            host = "mp3channels.webradio.antenne.de";       // DE Antenne Bayern - 80er Hits
            path = "/80er-kulthits";
            httpPort = 80;;
            break;
        case 5:
            nazev = "Antene Bayern 90";
            host = "mp3channels.webradio.antenne.de";     // DE Antenne Bayern - 90er Hits
            path = "/90er-hits";
            httpPort = 80;
            break;
        case 6:
            nazev = " Hitradio Orion"; // CZ Hitrádio Orion Morava
            host = "ice.abradio.cz";
            path = "/orionmorava128.mp3";
            httpPort = 8000;
            break;
        case 7:
            nazev = "HOT MIX Radio 90´s";             // FR HOT MUX Radio 90s
            host = "streaming.hotmixradio.fr";
            path = "/hotmixradio-90-128.mp3";
            httpPort = 80;
            break;
        case 8:
            nazev = " N-Joy Bulgaria";      // BG N-Joy Radio
            host = "strm112.1.fm";
            path = "/atr_mobile_mp3";
            httpPort =80;
            break;
        case 9:
            nazev = "Evropa 2 Top 40";      // CZ Evropa 2 Top 40
            host = "ice.actve.net";
            path = "/web-e2-top40";
            httpPort =80;
            break;
        case 10:
            nazev = "   KISS 98 FM";      // CZ Kiss 98 FM
            host = "icecast4.play.cz";
            path = "/kiss128.mp3";
            httpPort =80;
            break; 
        case 11:
            nazev = "Zlin Best Ballads";      // CZ Rádio Zlín Best Ballads
            host = "212.111.2.151";
            path = "/radiozlin_128.mp3";
            httpPort =8000;
            break;

         case 12:
            nazev = "Monte Carlo 98.2";    // Monako RMC 98.2
            host = "radiomonaco.ice.infomaniak.ch";
            path = "/radiomonaco-128.mp3";
            httpPort =80;
            break;

         case 13:
            nazev = " Cherie Ballads";    // FR Chérie Ballads
            host = "185.52.127.131";
            path = "/fr/30297/mp3_128.mp3";
            httpPort =80;
            break;

         case 14:
            nazev = "    Cherie FM";    // FR Chérie FM
            host = "185.52.127.163";
            path = "/fr/30201/mp3_128.mp3";
            httpPort =80;
            break;

         case 15:
            nazev = "   Cherie 80s";    // FR Chérie 80s
            host = "185.52.127.159";
            path = "/fr/30237/mp3_128.mp3?";
            httpPort =80;
            break; 

         case 16:
            nazev = " Athens Party GR";    // GR Athens Party
            host = "ice.onestreaming.com";
            path = "/athensparty";
            httpPort =80;
            break; 

         case 17:
            nazev = "    Radio Rubi"; 
            host = "icecast8.play.cz";       // Radio Rubi
            path = "/radiorubi128.mp3";
            httpPort =80;
            break;

         case 18:
            nazev = "   SKY Radio SK";    // SK SKY Rádio
            host = "stream.skyradio.sk";
            path = "/sky128";
            httpPort =8000;
            break;


    }

  
                                                      

    if(!client.connected() || pamet_ID_stanice!=ID_stanice){    
    
      if(client.connect(host, httpPort)){                                 // Adresa serveru se streamem - ve smyčce
       client.print(String("GET ") + path + " HTTP/1.1\r\n" +
                  "Host: " + host + "\r\n" + 
                  "Connection: close\r\n\r\n");
              pamet_ID_stanice=ID_stanice;
           
              lcd.clear(); 
              lcd.setCursor(2,0);
              lcd.print("Predvolba");
              lcd.setCursor(13,0);  
              lcd.print(ID_stanice);
              lcd.setCursor(0,1);
              lcd.print(nazev);
      }
     }
  
    if(client.available() > 0){                                          // Pokud je server dostupný, tak :
      uint8_t bytesread = client.read(mp3buff,32);                       // ulož přijatá data do bufferu
    MP3player.playChunk(mp3buff,bytesread);                              // a přehraj na VS1053B Shield
  
   }

}

// To je vše, příjemnou zábavu !                 David Kohout 12 / 2019
